Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
pyeditorjs/__init__.py | (no class) | 14 | 3 | 0 | 79%
pyeditorjs/blocks.py | EditorJsBlock | 4 | 3 | 0 | 25%
pyeditorjs/blocks.py | HeaderBlock | 9 | 1 | 0 | 89%
pyeditorjs/blocks.py | ParagraphBlock | 2 | 0 | 0 | 100%
pyeditorjs/blocks.py | ListBlock | 8 | 1 | 0 | 88%
pyeditorjs/blocks.py | DelimiterBlock | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ImageBlock | 10 | 1 | 0 | 90%
pyeditorjs/blocks.py | QuoteBlock | 7 | 7 | 0 | 0%
pyeditorjs/blocks.py | TableBlock | 11 | 11 | 0 | 0%
pyeditorjs/blocks.py | CodeBlock | 4 | 4 | 0 | 0%
pyeditorjs/blocks.py | WarningBlock | 6 | 6 | 0 | 0%
pyeditorjs/blocks.py | RawBlock | 4 | 4 | 0 | 0%
pyeditorjs/blocks.py | (no class) | 80 | 0 | 0 | 100%
pyeditorjs/exceptions.py | EditorJsException | 0 | 0 | 0 | 100%
pyeditorjs/exceptions.py | EditorJsParseError | 0 | 0 | 0 | 100%
pyeditorjs/exceptions.py | EditorJSUnsupportedBlock | 0 | 0 | 0 | 100%
pyeditorjs/exceptions.py | (no class) | 4 | 0 | 0 | 100%
pyeditorjs/parser.py | EditorJsParser | 19 | 6 | 0 | 68%
pyeditorjs/parser.py | (no class) | 15 | 0 | 0 | 100%
Total |  | 198 | 47 | 0 | 76%

No items found using the specified filter.